

import os
from addict import Dict
import requests


def envApiKey():
    return "SLASHML_API_KEY"


def apiRoot():
    return "https://api.slashml.com"


def baseUrl(service_name, version):
    return f"{apiRoot()}/{service_name}/{version}"


def generateURL(*path):
    return "/".join(d for d in path)


def generateHeaders(api_key):
    if api_key:
        return {"authorization": f"Token {api_key}"}
    if os.environ.get(envApiKey()):
        key_env = os.environ.get(envApiKey())
        return {"authorization": f"Token {key_env}"}
    log(noTokenWarning())
    return None


def formatResponse(response):
    if response.status_code == 500:
        return Dict({"status": "ERROR", "reason": response.text})
    elif response.status_code != 200:
        return Dict({"status": "ERROR", "reason": response.json()})
    return Dict(response.json())


def getTaskStatus(base_url, headers, job_id, service_provider):
    url = generateURL(base_url, "jobs", job_id)
    params = {"service_provider": service_provider.value}
    response = requests.get(url, headers=headers, params=params)
    return formatResponse(response)


def noTokenWarning():
    return "No API Key provided, there are certain limits to the usage"


def log(msg):
    print(msg)



from setuptools import setup, find_packages

import os
SLASHML_DIR = os.environ['SLASHML_DIR']

def read_req_file(req_type):
    with open(f"{SLASHML_DIR}requires-{req_type}.txt") as fp:  # pylint: disable=W1514
        requires = (line.strip() for line in fp)
        return [req for req in requires if req and not req.startswith("#")]

# Read the contents of the README file
with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="slashml",
    version="0.1.0",
    url="https://slashml.com/",
    author="eff-kay",
    author_email="faiizan14@gmail.com",
    description=(
        "A Python client for interacting with SlashML services" "Developed by SlashML."
    ),
    long_description=long_description,  # Use the contents of the README file
    long_description_content_type="text/markdown",  # Set the type of the README file
    packages=find_packages("."),
    package_dir={"": "."},
    install_requires=read_req_file("install"),
    license="MIT",
    python_requires=">=3.6",
)



import requests
import time

from enum import Enum
from .utils import generateURL, baseUrl, generateHeaders, formatResponse, getTaskStatus


class TextToSpeech:
    class ServiceProvider(Enum):
        GOOGLE = "google"
        AWS = "aws"

        @classmethod
        def choices(cls):
            return [key.value for key in cls]

    _base_url = baseUrl("text-to-speech", "v1")
    _headers = None

    def __init__(self, api_key: str = None):
        self._headers = generateHeaders(api_key)

    def submit_job(self, text: str, service_provider: ServiceProvider):
        url = generateURL(self._base_url, "jobs")
        payload = {"text": text, "service_provider": service_provider.value}
        response = requests.post(url, headers=self._headers, data=payload)
        return formatResponse(response)

    def status(self, job_id: str, service_provider: ServiceProvider):
        return getTaskStatus(self._base_url, self._headers, job_id, service_provider)
    
    def execute(self, text: str, service_provider: ServiceProvider):
        url = generateURL(self._base_url, "jobs")
        payload = {"text": text, "service_provider": service_provider.value}
        response = requests.post(url, headers=self._headers, data=payload)
        job = formatResponse(response)

        assert job.status != "ERROR", f"{job}"
        print(f"Got Job ID: {job.id}")

        # check job status
        response = getTaskStatus(self._base_url, self._headers, job.id, service_provider)

        while response.status == "IN_PROGRESS":
            time.sleep(5)
            response = getTaskStatus(self._base_url, self._headers, job.id, service_provider)
            print(f"Response = {response}. Retrying in 5 seconds")
        
        return response
